unquad.utils.data.load
======================

.. automodule:: unquad.utils.data.load

   
   .. rubric:: Functions

   .. autosummary::
   
      load_breast
      load_fraud
      load_ionosphere
      load_mammography
      load_musk
      load_shuttle
      load_thyroid
      load_wbc
   